# Sample Package Data


## Manifest

* `grid.npy`: Grid for plotting exact* vxc. 

* `vxc_be.npy`: Exact exchange-correlation potential for isolated beryllium. Kindly provided by Professor Cyrus Umrigar. 

* `vxc_ne.npy`: Exact exchange-correlation potential for isolated neon. Kindly provided by Professor Cyrus Umrigar. 

